==> openwebbeans-1.2.8-source-release.zip: openwebbeans-1.2.8/webbeans-impl/src/main/java/org/apache/webbeans/portable/events/discovery/AfterDeploymentValidationImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.portable.events.discovery;

import javax.enterprise.inject.spi.AfterDeploymentValidation;

import org.apache.webbeans.container.BeanManagerImpl;

/**
 * Event that is fired by the container after it validates
 * deployment.
 * 
 * @version $Rev: 1479382 $ $Date: 2013-05-05 22:28:06 +0200 (Sun, 05 May 2013) $
 *
 */
public class AfterDeploymentValidationImpl implements AfterDeploymentValidation
{
    private final BeanManagerImpl beanManagerImpl;

    public AfterDeploymentValidationImpl(BeanManagerImpl beanManagerImpl)
    {
        this.beanManagerImpl = beanManagerImpl;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void addDeploymentProblem(Throwable t)
    {
        beanManagerImpl.getErrorStack().pushError(t);
    }

}

==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/main/java/org/apache/webbeans/portable/events/discovery/AfterDeploymentValidationImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.portable.events.discovery;

import javax.enterprise.inject.spi.AfterDeploymentValidation;

import org.apache.webbeans.container.BeanManagerImpl;

/**
 * Event that is fired by the container after it validates
 * deployment.
 * 
 * @version $Rev: 1647256 $ $Date: 2014-12-22 09:18:57 +0100 (Mon, 22 Dec 2014) $
 *
 */
public class AfterDeploymentValidationImpl implements AfterDeploymentValidation
{
    private final BeanManagerImpl beanManagerImpl;
    private boolean started;

    public AfterDeploymentValidationImpl(BeanManagerImpl beanManagerImpl)
    {
        this.beanManagerImpl = beanManagerImpl;
    }

    public void setStarted()
    {
        started = true;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void addDeploymentProblem(Throwable t)
    {
        if (started)
        {
            throw new IllegalStateException("Only call container eevnt methods in their lifecycle");
        }
        beanManagerImpl.getErrorStack().pushError(t);
    }

}
